@@ -122,7 +122,7 @@ class NamespaceSerializer2(NamespaceSerializerBase):
             self._dump_protobuf(obj, variant, current_depth, config, log_errors)
         elif NamespaceSerializer2.is_bson(obj):
             self._dump_bson(obj, variant, current_depth, config, log_errors)
-        elif hasattr(obj, '__dict__'):
+        elif hasattr(obj, '__dict__') or hasattr(obj, '__slots__'):
             self._dump_user_class(obj, variant, current_depth, config, log_errors)
         else:
             self._dump_not_supported(obj, variant)
@@ -308,19 +308,20 @@ class NamespaceSerializer2(NamespaceSerializerBase):
 
         self.dump_variant_type(variant, variant_pb2.Variant.VARIANT_OBJECT)
 
-        for key, value in six.iteritems(obj.__dict__.copy()):
-            if key not in self.BUILTIN_ATTRIBUTES_IGNORE:
-                if object_weight >= config.max_depth:
-                    self.dump_variant_type(variant, variant_pb2.Variant.VARIANT_OBJECT, True)
-                    return
+        if getattr(obj, '__dict__', None) is not None:
+            for key, value in six.iteritems(obj.__dict__.copy()):
+                if key not in self.BUILTIN_ATTRIBUTES_IGNORE:
+                    if object_weight >= config.max_depth:
+                        self.dump_variant_type(variant, variant_pb2.Variant.VARIANT_OBJECT, True)
+                        return
 
-                variant.attribute_names_in_cache.append(self._get_string_index_in_cache(key))
-                attribute_value_variant = variant.attribute_values.add()
-                self.estimated_pending_bytes += 6  # Header + number + header + size
+                    variant.attribute_names_in_cache.append(self._get_string_index_in_cache(key))
+                    attribute_value_variant = variant.attribute_values.add()
+                    self.estimated_pending_bytes += 6  # Header + number + header + size
 
-                self._dump_python_object(value, attribute_value_variant, object_weight, config, log_errors)
+                    self._dump_python_object(value, attribute_value_variant, object_weight, config, log_errors)
 
-        if hasattr(obj, '__slots__') and obj.__slots__:
+        if getattr(obj, '__slots__', None) is not None:
             items = obj.__slots__
             # py4j (used by pyspark to communicate with Java proxy objects) sets __slots__ to Java proxy objects,
             # and supports __dir__ instead.
