@@ -340,17 +340,20 @@ void BytecodeBreakpoint::PatchCodeObject(CodeObjectBreakpoints* code) {
             << " from patched " << code->zombie_refs.back().get();
     Py_INCREF(code_object->co_code);
 
-
 #if PY_VERSION_HEX >= 0x030A0000
-    PyObject* line_table = code_object->co_linetable;
-#else
-    PyObject* line_table = code_object->co_lnotab;
-#endif
-    if (line_table != nullptr) {
-      code->zombie_refs.push_back(ScopedPyObject(line_table));
+    if (code_object->co_linetable != nullptr) {
+      code->zombie_refs.push_back(ScopedPyObject(code_object->co_linetable));
     }
-    line_table = code->original_lnotab.get();
-    Py_INCREF(line_table);
+    code_object->co_linetable = code->original_lnotab.get();
+    Py_INCREF(code_object->co_linetable);
+
+#else
+    if (code_object->co_lnotab != nullptr) {
+      code->zombie_refs.push_back(ScopedPyObject(code_object->co_lnotab));
+    }
+    code_object->co_lnotab = code->original_lnotab.get();
+    Py_INCREF(code_object->co_lnotab);
+#endif
 
     return;
   }
@@ -453,17 +456,19 @@ void BytecodeBreakpoint::PatchCodeObject(CodeObjectBreakpoints* code) {
           << ", original was " << code->original_code.get();
 
   if (has_lnotab) {
-#if PY_VERSION_HEX >= 0x030A0000
-    PyObject* line_table = code_object->co_linetable;
-#else
-    PyObject* line_table = code_object->co_lnotab;
-#endif
-    code->zombie_refs.push_back(ScopedPyObject(line_table));
-    ScopedPyObject lnotab_string(PyBytes_FromStringAndSize(
+  ScopedPyObject lnotab_string(PyBytes_FromStringAndSize(
         reinterpret_cast<const char*>(bytecode_manipulator.lnotab().data()),
         bytecode_manipulator.lnotab().size()));
     DCHECK(!lnotab_string.is_null());
-    line_table = lnotab_string.release();
+
+#if PY_VERSION_HEX >= 0x030A0000
+    code->zombie_refs.push_back(ScopedPyObject(code_object->co_linetable));
+    code_object->co_linetable = lnotab_string.release();
+#else
+    code->zombie_refs.push_back(ScopedPyObject(code_object->co_lnotab));
+    code_object->co_lnotab = lnotab_string.release();
+#endif
+
   }
 
   // Invoke error callback after everything else is done. The callback may
