@@ -424,6 +424,17 @@ static OpcodeMutableStatus IsOpcodeMutable(const uint8 opcode) {
     case CALL_FUNCTION_VAR_KW:
     case MAKE_CLOSURE:
 #endif
+#if PY_VERSION_HEX >= 0x030A0000
+    case COPY_DICT_WITHOUT_KEYS:
+    case GET_LEN:
+    case MATCH_MAPPING:
+    case MATCH_SEQUENCE:
+    case MATCH_KEYS:
+    case MATCH_CLASS:
+    case GEN_START:
+    case ROT_N:
+#endif
+
       return OPCODE_NOT_MUTABLE;
 
     case PRINT_EXPR:
