@@ -30,7 +30,11 @@ static PyObject* g_debuglet_module = nullptr;
 
 CodeObjectLinesEnumerator::CodeObjectLinesEnumerator(
     PyCodeObject* code_object) {
-  Initialize(code_object->co_firstlineno, code_object->co_lnotab);
+#if PY_VERSION_HEX >= 0x030A0000
+    Initialize(code_object->co_firstlineno, code_object->co_linetable);
+#else
+    Initialize(code_object->co_firstlineno, code_object->co_lnotab);
+#endif
 }
 
 
