@@ -18,11 +18,7 @@ class UserWarnings(object):
 
     @classmethod
     def set_reporter(cls, warning_reporter):
-        if hasattr(cls._tls, "warning_reporter"):
-            old_value = cls._tls.warning_reporter
-        else:
-            old_value = None
-
+        old_value = getattr(cls._tls, "warning_reporter", None)
         cls._tls.warning_reporter = warning_reporter
         return old_value
 
